### R code from vignette source 'dcemriS4.Rnw'

###################################################
### code chunk number 1: preliminaries
###################################################
library("dcemriS4")
## options(niftiAuditTrail=FALSE)
options(width=85)
require("oro.nifti")
require("minpack.lm")
require("bitops")


###################################################
### code chunk number 2: doubleanglemethod
###################################################
sdam60 <- readNIfTI(system.file("nifti/SDAM_ep2d_60deg_26slc.nii.gz", 
                                package="dcemriS4"))
sdam60
sdam120 <- readNIfTI(system.file("nifti/SDAM_ep2d_120deg_26slc.nii.gz", 
                                 package="dcemriS4"))
sdam120
sdam.image <- rowMeans(dam(sdam60, sdam120, 60), dims=3)
mask <- (rowSums(sdam60, dims=3) > 500) # nifti(rowSums(sdam60, dims=3) > 500)


###################################################
### code chunk number 3: figure5-png
###################################################
png("sdam.png", width=400, height=400)


###################################################
### code chunk number 4: figure5-code
###################################################
# A smooth version of "sdam.image"
SDAM <- readNIfTI(system.file("nifti/SDAM_smooth.nii.gz", package="dcemriS4"))
overlay(sdam120, ifelse(mask, SDAM, NA), z=13, zlim.x=range(sdam120), 
        zlim.y=c(0.5,1.5), plot.type="single")


###################################################
### code chunk number 5: figure5-dev.off
###################################################
dev.off()


###################################################
### code chunk number 6: t1estimation
###################################################
fnames <- c("fl3d_vibe-5deg","fl3d_vibe-10deg","fl3d_vibe-20deg",
            "fl3d_vibe-25deg","fl3d_vibe-15deg")
alpha <- c(5, 10, 20, 25, 15)
nangles <- length(alpha)
X <- Y <- 64
Z <- 36
flip <- fangles <- array(0, c(X,Y,Z,nangles))
for (w in 1:nangles) {
  vibe <- readNIfTI(system.file(paste("nifti/", fnames[w], ".nii.gz", sep=""), 
                                package="dcemriS4"))
  flip[,,1:nsli(vibe),w] <- vibe
  fangles[,,,w] <- array(alpha[w], c(X,Y,Z))
}
TR <- 4.22 / 1000 # seconds
fanglesB1 <- fangles * array(SDAM, c(X,Y,Z,nangles))
zi <- 10:13
maskzi <- mask
maskzi[,,(! 1:Z %in% zi)] <- FALSE
R1 <- R1.fast(flip, maskzi, fanglesB1, TR, verbose=TRUE)


###################################################
### code chunk number 7: figure6-png
###################################################
png("t1_phantom.png", width=400, height=400)


###################################################
### code chunk number 8: figure6-code
###################################################
overlay(vibe, 1/R1$R10[,,1:nsli(vibe)], z=13, zlim.x=c(0,1024), 
        zlim.y=c(0,2.5), plot.type="single")


###################################################
### code chunk number 9: figure6-dev.off
###################################################
dev.off()


###################################################
### code chunk number 10: FSLmask
###################################################
t1pmask <- readNIfTI(system.file("nifti/t1_phantom_mask.nii.gz", 
                                 package="dcemriS4"))
pmask <- nifti(array(t1pmask[,,25], dim(t1pmask))) # repeat slice #25
pmask


###################################################
### code chunk number 11: figure7
###################################################
T1 <- c(.484,.350,1.07,.648,.456,1.07,.660,1.543,1.543,.353)
par(mfrow=c(1,1), mar=c(5,4,4,2)+.1)
boxplot(split(1/drop(R1$R10), as.factor(drop(pmask)))[-1], 
        ylim=c(0,2.5), xlab="Region of Interest", ylab="T1 (seconds)")
points(1:10, T1, col=rainbow(10), pch=16, cex=2)


###################################################
### code chunk number 12: buckley.aif
###################################################
data("buckley")
aifparams <- with(buckley, orton.exp.lm(time.min, input))
fit.aif <- with(aifparams, aif.orton.exp(buckley$time.min, AB, muB, AG, muG))


###################################################
### code chunk number 13: figure8
###################################################
with(buckley, plot(time.min, input, type="l", lwd=2, xlab="Time (minutes)", 
                   ylab=""))
with(buckley, lines(time.min, fit.aif, lwd=2, col=2))
legend("topright", c("Simulated AIF", "Estimated AIF"), lwd=2, col=1:2)


###################################################
### code chunk number 14: buckley.kinetic
###################################################
xi <- seq(5, 300, by=5)
img <- array(t(breast$data)[,xi], c(13,1,1,60))
time <- buckley$time.min[xi]
aif <- buckley$input[xi]
mask <- array(TRUE, dim(img)[1:3])
aifparams <- orton.exp.lm(time, aif)
fit <- dcemri.lm(img, time, mask, model="orton.exp",
                 aif="user", user=aifparams)


###################################################
### code chunk number 15: figure9
###################################################
par(mfrow=c(4,4), mar=c(5,4,4,2)/1.25, mex=0.8)
for (x in 1:nrow(img)) {
  plot(time, img[x,1,1,], ylim=range(img), xlab="Time (minutes)",
       ylab="", main=paste("Series", x))
  kinparams <- with(fit, c(vp[x,1,1], ktrans[x,1,1], kep[x,1,1]))
  lines(time, model.orton.exp(time, aifparams[1:4], kinparams), 
        lwd=1.5, col=2)
}


